
# ----------------------------------------------------------------------
# | Copyright  Unpublished, Rational Software Corporation. All Rights |
# | Reserved.  This software contains proprietary and confidential     |
# | information of Rational and its suppliers.  Use, disclosure or     |
# | reproduction is prohibited without the prior express written       |
# | consent of Rational Software Corporation.                          |
# ----------------------------------------------------------------------

#
# FILE: ccpb_ucm_config.pl
#
# PURPOSE: This ccperl script creates the element type and trigger types
#          used to manage PowerBuilder Libraries during UCM operations.
#
#          This script should be executed in each VOB used to store
#          PowerBuilder objects.
#

use ClearCase::CurrentVersion;

if ( $atria_home = ClearCase::CurrentVersion::SetProductHomeEV )
{
    # record the location of the trigger scripts to be used
    $deliver_script = "$atria_home\\bin\\ccpb_deliver.pl";
    $rebase_script = "$atria_home\\bin\\ccpb_rebase.pl";

    # make the element type (powerbuilder_library) used to manage PowerBuilder libraries
    $cmd = `cleartool mkeltype -nc -sup compressed_file -merge never powerbuilder_library`;
    print "$cmd\n";

    # apply the trigger which will recreate PowerBuilder libraries on a UCM deliver
    $cmd = `cleartool mktrtype -nc -ucmobject -all -postop deliver_start -execwin \"ccperl     \\\"$deliver_script\\\"\" CCPB_DELIVER`;
    print "$cmd\n";

    # apply the trigger which will recreate PowerBuilder libraries on a UCM rebase
    $cmd = `cleartool mktrtype -nc -ucmobject -all -postop rebase_start -execwin \"ccperl     \\\"$rebase_script\\\"\" CCPB_REBASE`;
    print "$cmd\n";
}
else
{
    print "Unable to determine ClearCase install directory.  Aborting configuration.\n";
}
